## Random Helper Module

First, install:

`$ pip install AustinWolffHelperFunction`

Then, you can import the following modules **from lambdata_austinwolff**:

```
from lambdata_austinwolff import helper_function
from lambdata_austinwolff import vehicle
from lambdata_austinwolff import student
```

This module can:
1. Remove IQR outliers from a dataframe (analyzed by column) and
2. Return random seed phrases.

See [helper_function.py](https://github.com/AustinJamesWolff/lambdata-ds33/blob/master/src/lambdata-austinwolff/helper_function.py) for more information.